@@ -9,7 +9,7 @@ from fastapi.middleware.cors import CORSMiddleware
 from starlette.staticfiles import StaticFiles
 
 from lightning_app.frontend.frontend import Frontend
-from lightning_app.utilities.log import get_frontend_logfile
+from lightning_app.utilities.log import get_logfile
 from lightning_app.utilities.network import find_free_network_port
 
 
@@ -20,6 +20,7 @@ class StaticWebFrontend(Frontend):
 
     Arguments:
         serve_dir: A local directory to serve files from. This directory should at least contain a file `index.html`.
+        root_path: A path prefix when routing traffic from behind a proxy at `/<root_path>`
 
     Example:
 
@@ -36,16 +37,17 @@ class StaticWebFrontend(Frontend):
         self.serve_dir = serve_dir
         self._process: Optional[mp.Process] = None
 
-    def start_server(self, host: str, port: int) -> None:
-        log_file = str(get_frontend_logfile())
+    def start_server(self, host: str, port: int, root_path: str = "") -> None:
+        log_file = str(get_logfile())
         self._process = mp.Process(
-            target=start_server,
+            target=_start_server,
             kwargs=dict(
                 host=host,
                 port=port,
                 serve_dir=self.serve_dir,
                 path=f"/{self.flow.name}",
                 log_file=log_file,
+                root_path=root_path,
             ),
         )
         self._process.start()
@@ -56,12 +58,14 @@ class StaticWebFrontend(Frontend):
         self._process.kill()
 
 
-def healthz():
+def _healthz():
     """Health check endpoint used in the cloud FastAPI servers to check the status periodically."""
     return {"status": "ok"}
 
 
-def start_server(serve_dir: str, host: str = "localhost", port: int = -1, path: str = "/", log_file: str = "") -> None:
+def _start_server(
+    serve_dir: str, host: str = "localhost", port: int = -1, path: str = "/", log_file: str = "", root_path: str = ""
+) -> None:
     if port == -1:
         port = find_free_network_port()
     fastapi_service = FastAPI()
@@ -75,12 +79,12 @@ def start_server(serve_dir: str, host: str = "localhost", port: int = -1, path:
     )
     # trailing / is required for urljoin to properly join the path. In case of
     # multiple trailing /, urljoin removes them
-    fastapi_service.get(urljoin(f"{path}/", "healthz"), status_code=200)(healthz)
-    fastapi_service.mount(path, StaticFiles(directory=serve_dir, html=True), name="static")
+    fastapi_service.get(urljoin(f"{path}/", "healthz"), status_code=200)(_healthz)
+    fastapi_service.mount(urljoin(path, root_path), StaticFiles(directory=serve_dir, html=True), name="static")
 
     log_config = _get_log_config(log_file) if log_file else uvicorn.config.LOGGING_CONFIG
 
-    uvicorn.run(app=fastapi_service, host=host, port=port, log_config=log_config)
+    uvicorn.run(app=fastapi_service, host=host, port=port, log_config=log_config, root_path=root_path)
 
 
 def _get_log_config(log_file: str) -> dict:
@@ -115,7 +119,8 @@ def _get_log_config(log_file: str) -> dict:
 if __name__ == "__main__":  # pragma: no-cover
     parser = ArgumentParser()
     parser.add_argument("serve_dir", type=str)
+    parser.add_argument("root_path", type=str, default="")
     parser.add_argument("--host", type=str, default="localhost")
     parser.add_argument("--port", type=int, default=-1)
     args = parser.parse_args()
-    start_server(serve_dir=args.serve_dir, host=args.host, port=args.port)
+    _start_server(serve_dir=args.serve_dir, host=args.host, port=args.port, root_path=args.root_path)
