@@ -1,5 +1,5 @@
 from time import time
-from typing import List
+from typing import List, Optional
 
 import lightning_app
 from lightning_app.core.queues import QueuingSystem
@@ -7,6 +7,12 @@ from lightning_app.runners.backends.backend import Backend
 
 
 class DockerBackend(Backend):
+    def resolve_url(self, app, base_url: Optional[str] = None) -> None:
+        pass
+
+    def stop_work(self, app: "lightning_app.LightningApp", work: "lightning_app.LightningWork") -> None:
+        pass
+
     def __init__(self, entrypoint_file: str):
         super().__init__(entrypoint_file=entrypoint_file, queues=QueuingSystem.REDIS, queue_id=str(int(time())))
 
