@@ -6,7 +6,7 @@ from copy import deepcopy
 from time import sleep, time
 from typing import Dict, List, Optional, Union
 
-from lightning_app.storage.path import filesystem, LocalFileSystem, shared_storage_path
+from lightning_app.storage.path import _filesystem, _shared_storage_path, LocalFileSystem
 from lightning_app.utilities.component import _is_flow_context
 
 
@@ -34,11 +34,25 @@ class Drive:
                 When not provided, it is automatically inferred by Lightning.
             root_folder: This is the folder from where the Drive perceives the data (e.g this acts as a mount dir).
         """
+        if id.startswith("s3://"):
+            raise ValueError(
+                "Using S3 buckets in a Drive is no longer supported. Please pass an S3 `Mount` to "
+                "a Work's CloudCompute config in order to mount an s3 bucket as a filesystem in a work.\n"
+                f"`CloudCompute(mount=Mount({id}), ...)`"
+            )
+
         self.id = None
+        self.protocol = None
         for protocol in self.__PROTOCOLS__:
             if id.startswith(protocol):
                 self.protocol = protocol
                 self.id = id.replace(protocol, "")
+                break
+        else:  # N.B. for-else loop
+            raise ValueError(
+                f"Unknown protocol for the drive 'id' argument '{id}`. The 'id' string "
+                f"must start with one of the following prefixes {self.__PROTOCOLS__}"
+            )
 
         if not self.id:
             raise Exception(f"The Drive id needs to start with one of the following protocols: {self.__PROTOCOLS__}")
@@ -47,11 +61,11 @@ class Drive:
             raise Exception(f"The id should be unique to identify your drive. Found `{self.id}`.")
 
         self.root_folder = pathlib.Path(root_folder).resolve() if root_folder else pathlib.Path(os.getcwd())
-        if not os.path.isdir(self.root_folder):
+        if self.protocol != "s3://" and not os.path.isdir(self.root_folder):
             raise Exception(f"The provided root_folder isn't a directory: {root_folder}")
         self.component_name = component_name
         self.allow_duplicates = allow_duplicates
-        self.fs = filesystem()
+        self.fs = _filesystem()
 
     @property
     def root(self) -> pathlib.Path:
@@ -62,7 +76,7 @@ class Drive:
 
     @property
     def drive_root(self) -> pathlib.Path:
-        drive_root = shared_storage_path() / "artifacts" / "drive" / self.id
+        drive_root = _shared_storage_path() / "artifacts" / "drive" / self.id
         return drive_root
 
     def put(self, path: str) -> None:
@@ -81,12 +95,12 @@ class Drive:
         if not self.allow_duplicates:
             self._check_for_allow_duplicates(path)
 
-        from lightning_app.storage.copier import copy_files
+        from lightning_app.storage.copier import _copy_files
 
         src = pathlib.Path(os.path.join(self.root_folder, path)).resolve()
         dst = self._to_shared_path(path, component_name=self.component_name)
 
-        copy_files(src, dst)
+        _copy_files(src, dst)
 
     def list(self, path: Optional[str] = ".", component_name: Optional[str] = None) -> List[str]:
         """This method enables to list files under the provided path from the Drive in a blocking fashion.
@@ -231,6 +245,9 @@ class Drive:
     def _collect_component_names(self) -> List[str]:
         sep = "/"
         if self.fs.exists(self.drive_root):
+            # Invalidate cache before running ls in case new directories have been added
+            # TODO: Re-evaluate this - may lead to performance issues
+            self.fs.invalidate_cache()
             return [str(p.split(sep)[-1]) for p in self.fs.ls(self.drive_root)]
         return []
 
