@@ -3,7 +3,6 @@ import sys
 from queue import Empty
 from typing import List, Optional, Tuple
 
-import pytest
 from packaging.version import Version
 
 from lightning_app import LightningFlow, LightningWork
@@ -15,7 +14,7 @@ from lightning_app.utilities.imports import (
 )
 
 
-def call_script(
+def _call_script(
     filepath: str,
     args: Optional[List[str]] = None,
     timeout: Optional[int] = 60 * 10,
@@ -35,14 +34,14 @@ def call_script(
     return p.returncode, stdout, stderr
 
 
-def run_script(filepath):
-    code, stdout, stderr = call_script(filepath)
+def _run_script(filepath):
+    code, stdout, stderr = _call_script(filepath)
     print(f"{filepath} STDOUT: {stdout}")
     print(f"{filepath} STDERR: {stderr}")
     assert not code, code
 
 
-class RunIf:
+class _RunIf:
     """RunIf wrapper for simple marking specific cases, fully compatible with pytest.mark::
 
     @RunIf(...)
@@ -54,7 +53,7 @@ class RunIf:
     def __new__(
         self,
         *args,
-        pytorch_lightning: bool = False,
+        pl: bool = False,
         flash: bool = False,
         min_python: Optional[str] = None,
         skip_windows: bool = False,
@@ -64,10 +63,12 @@ class RunIf:
         cloud: bool = False,
         **kwargs,
     ):
+        import pytest
+
         """
         Args:
             *args: Any :class:`pytest.mark.skipif` arguments.
-            pytorch_lightning: Requires that PyTorch Lightning is installed.
+            pl: Requires that PyTorch Lightning is installed.
             flash: Requires that Flash is installed.
             min_python: Require that Python is greater or equal than this version.
             skip_windows: Skip for Windows platform.
@@ -95,7 +96,7 @@ class RunIf:
             conditions.append(sys.platform == "darwin")
             reasons.append("unimplemented on MacOS")
 
-        if pytorch_lightning:
+        if pl:
             conditions.append(not _is_pytorch_lightning_available())
             reasons.append("PyTorch Lightning is required.")
 
@@ -113,7 +114,7 @@ class RunIf:
         )
 
 
-class MockQueue(BaseQueue):
+class _MockQueue(BaseQueue):
     def __init__(self, name: str = "", default_timeout: float = 0):
         super().__init__(name, default_timeout)
         self._queue = []
