@@ -3,7 +3,8 @@ from dataclasses import asdict, dataclass, field
 from typing import Optional, Union
 
 import yaml
-from lightning_cloud.utils.name_generator import get_unique_name
+
+from lightning_app.utilities.name_generator import get_unique_name
 
 _APP_CONFIG_FILENAME = ".lightning"
 
@@ -17,6 +18,7 @@ class AppConfig:
     """
 
     name: str = field(default_factory=get_unique_name)
+    cluster_id: Optional[str] = field(default=None)
 
     def save_to_file(self, path: Union[str, pathlib.Path]) -> None:
         """Save the configuration to the given file in YAML format."""
@@ -26,7 +28,7 @@ class AppConfig:
 
     def save_to_dir(self, directory: Union[str, pathlib.Path]) -> None:
         """Save the configuration to a file '.lightning' to the given folder in YAML format."""
-        self.save_to_file(pathlib.Path(directory, _APP_CONFIG_FILENAME))
+        self.save_to_file(_get_config_file(directory))
 
     @classmethod
     def load_from_file(cls, path: Union[str, pathlib.Path]) -> "AppConfig":
@@ -45,22 +47,14 @@ class AppConfig:
         return cls.load_from_file(pathlib.Path(directory, _APP_CONFIG_FILENAME))
 
 
-def find_config_file(source_path: pathlib.Path = pathlib.Path.cwd()) -> Optional[pathlib.Path]:
-    """Search for the Lightning app config file '.lightning' at the given source path.
-
-    Relative to the given path, it will search for the '.lightning' config file by going up the directory structure
-    until found. Returns ``None`` if no config file is found in any of the parent directories.
+def _get_config_file(source_path: Union[str, pathlib.Path]) -> pathlib.Path:
+    """Get the Lightning app config file '.lightning' at the given source path.
 
     Args:
-        source_path: A path to a folder or a file. The search for the config file will start relative to this path.
+        source_path: A path to a folder or a file.
     """
     source_path = pathlib.Path(source_path).absolute()
     if source_path.is_file():
         source_path = source_path.parent
 
-    candidate = pathlib.Path(source_path / _APP_CONFIG_FILENAME)
-    if candidate.is_file():
-        return candidate
-
-    if source_path.parents:
-        return find_config_file(source_path.parent)
+    return pathlib.Path(source_path / _APP_CONFIG_FILENAME)
