@@ -7,11 +7,12 @@ import threading
 import time
 import traceback
 import warnings
+from contextlib import contextmanager
 from copy import deepcopy
 from dataclasses import dataclass, field
 from functools import partial
 from threading import Event, Thread
-from typing import Any, Callable, Dict, Optional, Set, Tuple, Type, TYPE_CHECKING, Union
+from typing import Any, Callable, Dict, Generator, Optional, Set, Tuple, Type, TYPE_CHECKING, Union
 
 from deepdiff import DeepDiff, Delta
 from lightning_utilities.core.apply_func import apply_to_collection
@@ -102,8 +103,6 @@ class ProxyWorkRun:
     caller_queue: "BaseQueue"
 
     def __post_init__(self):
-        self.cache_calls = self.work.cache_calls
-        self.parallel = self.work.parallel
         self.work_state = None
 
     def __call__(self, *args, **kwargs):
@@ -122,7 +121,7 @@ class ProxyWorkRun:
 
         # The if/else conditions are left un-compressed to simplify readability
         # for the readers.
-        if self.cache_calls:
+        if self.work.cache_calls:
             if not entered or stopped_on_sigterm:
                 _send_data_to_caller_queue(self, self.work, self.caller_queue, data, call_hash)
             else:
@@ -136,7 +135,7 @@ class ProxyWorkRun:
                     # the previous task has completed and we can re-queue the next one.
                     # overriding the return value for next loop iteration.
                     _send_data_to_caller_queue(self, self.work, self.caller_queue, data, call_hash)
-        if not self.parallel:
+        if not self.work.parallel:
             raise CacheMissException("Task never called before. Triggered now")
 
     def _validate_call_args(self, args: Tuple[Any, ...], kwargs: Dict[str, Any]) -> None:
@@ -314,7 +313,7 @@ class LightningWorkSetAttrProxy:
     work_name: str
     work: "LightningWork"
     delta_queue: "BaseQueue"
-    state_observer: "WorkStateObserver"
+    state_observer: Optional["WorkStateObserver"]
 
     def __call__(self, name: str, value: Any) -> None:
         logger.debug(f"Setting {name}: {value}")
@@ -329,7 +328,8 @@ class LightningWorkSetAttrProxy:
             self.delta_queue.put(ComponentDelta(id=self.work_name, delta=delta))
 
             # add the delta to the buffer to let WorkStateObserver know we already sent this one to the Flow
-            self.state_observer._delta_memory.append(delta)
+            if self.state_observer:
+                self.state_observer._delta_memory.append(delta)
 
 
 @dataclass
@@ -343,10 +343,36 @@ class WorkRunExecutor:
 
     work: "LightningWork"
     work_run: Callable
+    delta_queue: "BaseQueue"
+    enable_start_observer: bool = True
 
     def __call__(self, *args, **kwargs):
         return self.work_run(*args, **kwargs)
 
+    @contextmanager
+    def enable_spawn(self) -> Generator:
+        self.work._setattr_replacement = None
+        self.work._backend = None
+        self._clean_queues()
+        yield
+
+    def _clean_queues(self):
+        if "LIGHTNING_APP_STATE_URL" in os.environ:
+            self.work._request_queue = self.work._request_queue.to_dict()
+            self.work._response_queue = self.work._response_queue.to_dict()
+
+    @staticmethod
+    def process_queue(queue):
+        from lightning_app.core.queues import HTTPQueue, RedisQueue
+
+        if isinstance(queue, dict):
+            queue_type = queue.pop("type")
+            if queue_type == "redis":
+                return RedisQueue.from_dict(queue)
+            else:
+                return HTTPQueue.from_dict(queue)
+        return queue
+
 
 @dataclass
 class WorkRunner:
@@ -442,12 +468,13 @@ class WorkRunner:
         self._transfer_path_attributes()
 
         # 6. Create the state observer thread.
-        self.state_observer = WorkStateObserver(
-            self.work,
-            delta_queue=self.delta_queue,
-            flow_to_work_delta_queue=self.flow_to_work_delta_queue,
-            error_queue=self.error_queue,
-        )
+        if self.run_executor_cls.enable_start_observer:
+            self.state_observer = WorkStateObserver(
+                self.work,
+                delta_queue=self.delta_queue,
+                flow_to_work_delta_queue=self.flow_to_work_delta_queue,
+                error_queue=self.error_queue,
+            )
 
         # 7. Deepcopy the work state and send the first `RUNNING` status delta to the flow.
         reference_state = deepcopy(self.work.state)
@@ -478,12 +505,13 @@ class WorkRunner:
         # 11. Start the state observer thread. It will look for state changes and send them back to the Flow
         # The observer has to be initialized here, after the set_state call above so that the thread can start with
         # the proper initial state of the work
-        self.state_observer.start()
+        if self.run_executor_cls.enable_start_observer:
+            self.state_observer.start()
 
         # 12. Run the `work_run` method.
         # If an exception is raised, send a `FAILED` status delta to the flow and call the `on_exception` hook.
         try:
-            ret = self.run_executor_cls(self.work, work_run)(*args, **kwargs)
+            ret = self.run_executor_cls(self.work, work_run, self.delta_queue)(*args, **kwargs)
         except LightningSigtermStateException as e:
             raise e
         except BaseException as e:
@@ -500,7 +528,7 @@ class WorkRunner:
                     used_runpy = True
                 if user_exception:
                     trace.append(p)
-                if "ret = self.run_executor_cls(self.work, work_run)(*args, **kwargs)" in p:
+                if "ret = self.run_executor_cls(" in p:
                     user_exception = True
 
             if used_runpy:
@@ -525,7 +553,8 @@ class WorkRunner:
             return
 
         # 13. Destroy the state observer.
-        self.state_observer.join(0)
+        if self.run_executor_cls.enable_start_observer:
+            self.state_observer.join(0)
         self.state_observer = None
 
         # 14. Copy all artifacts to the shared storage so other Works can access them while this Work gets scaled down
@@ -574,14 +603,7 @@ class WorkRunner:
         raise LightningSigtermStateException(0)
 
     def _proxy_setattr(self, cleanup: bool = False):
-        if cleanup:
-            setattr_proxy = None
-        else:
-            assert self.state_observer
-            setattr_proxy = LightningWorkSetAttrProxy(
-                self.work_name, self.work, delta_queue=self.delta_queue, state_observer=self.state_observer
-            )
-        self.work._setattr_replacement = setattr_proxy
+        _proxy_setattr(self.work, self.delta_queue, self.state_observer, cleanup=cleanup)
 
     def _process_call_args(
         self, args: Tuple[Any, ...], kwargs: Dict[str, Any]
@@ -688,3 +710,16 @@ def persist_artifacts(work: "LightningWork") -> None:
             f"All {destination_paths} artifacts from Work {work.name} successfully "
             "stored at {artifacts_path(work.name)}."
         )
+
+
+def _proxy_setattr(work, delta_queue, state_observer: Optional[WorkStateObserver], cleanup: bool = False):
+    if cleanup:
+        setattr_proxy = None
+    else:
+        setattr_proxy = LightningWorkSetAttrProxy(
+            work.name,
+            work,
+            delta_queue=delta_queue,
+            state_observer=state_observer,
+        )
+    work._setattr_replacement = setattr_proxy
